Documentation
¶
Overview ¶
This package has the automatically generated clientset.
Index ¶
- type Clientset
- func (c *Clientset) Allocation() allocationv1alpha1.AllocationV1alpha1Interfacedeprecated
- func (c *Clientset) AllocationV1alpha1() allocationv1alpha1.AllocationV1alpha1Interface
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) Multicluster() multiclusterv1alpha1.MulticlusterV1alpha1Interfacedeprecated
- func (c *Clientset) MulticlusterV1alpha1() multiclusterv1alpha1.MulticlusterV1alpha1Interface
- func (c *Clientset) Stable() stablev1alpha1.StableV1alpha1Interfacedeprecated
- func (c *Clientset) StableV1alpha1() stablev1alpha1.StableV1alpha1Interface
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
type Clientset struct {
*discovery.DiscoveryClient
// contains filtered or unexported fields
}
Clientset contains the clients for groups. Each group has exactly one version included in a Clientset.
func NewForConfig ¶
NewForConfig creates a new Clientset for the given config.
func NewForConfigOrDie ¶
NewForConfigOrDie creates a new Clientset for the given config and panics if there is an error in the config.
func (*Clientset) Allocation
deprecated
added in
v0.10.0
func (c *Clientset) Allocation() allocationv1alpha1.AllocationV1alpha1Interface
Deprecated: Allocation retrieves the default version of AllocationClient. Please explicitly pick a version.
func (*Clientset) AllocationV1alpha1 ¶ added in v0.10.0
func (c *Clientset) AllocationV1alpha1() allocationv1alpha1.AllocationV1alpha1Interface
AllocationV1alpha1 retrieves the AllocationV1alpha1Client
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
Discovery retrieves the DiscoveryClient
func (*Clientset) Multicluster
deprecated
added in
v0.10.0
func (c *Clientset) Multicluster() multiclusterv1alpha1.MulticlusterV1alpha1Interface
Deprecated: Multicluster retrieves the default version of MulticlusterClient. Please explicitly pick a version.
func (*Clientset) MulticlusterV1alpha1 ¶ added in v0.10.0
func (c *Clientset) MulticlusterV1alpha1() multiclusterv1alpha1.MulticlusterV1alpha1Interface
MulticlusterV1alpha1 retrieves the MulticlusterV1alpha1Client
func (*Clientset) Stable
deprecated
func (c *Clientset) Stable() stablev1alpha1.StableV1alpha1Interface
Deprecated: Stable retrieves the default version of StableClient. Please explicitly pick a version.
func (*Clientset) StableV1alpha1 ¶
func (c *Clientset) StableV1alpha1() stablev1alpha1.StableV1alpha1Interface
StableV1alpha1 retrieves the StableV1alpha1Client
type Interface ¶
type Interface interface {
Discovery() discovery.DiscoveryInterface
AllocationV1alpha1() allocationv1alpha1.AllocationV1alpha1Interface
// Deprecated: please explicitly pick a version if possible.
Allocation() allocationv1alpha1.AllocationV1alpha1Interface
MulticlusterV1alpha1() multiclusterv1alpha1.MulticlusterV1alpha1Interface
// Deprecated: please explicitly pick a version if possible.
Multicluster() multiclusterv1alpha1.MulticlusterV1alpha1Interface
StableV1alpha1() stablev1alpha1.StableV1alpha1Interface
// Deprecated: please explicitly pick a version if possible.
Stable() stablev1alpha1.StableV1alpha1Interface
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
typed
|
|
|
allocation/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
allocation/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
multicluster/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
multicluster/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
stable/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
stable/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |