Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AgonesV1Client ¶
type AgonesV1Client struct {
// contains filtered or unexported fields
}
AgonesV1Client is used to interact with features provided by the agones.dev group.
func New ¶
func New(c rest.Interface) *AgonesV1Client
New creates a new AgonesV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AgonesV1Client, error)
NewForConfig creates a new AgonesV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶ added in v1.26.0
NewForConfigAndClient creates a new AgonesV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AgonesV1Client
NewForConfigOrDie creates a new AgonesV1Client for the given config and panics if there is an error in the config.
func (*AgonesV1Client) Fleets ¶
func (c *AgonesV1Client) Fleets(namespace string) FleetInterface
func (*AgonesV1Client) GameServerSets ¶
func (c *AgonesV1Client) GameServerSets(namespace string) GameServerSetInterface
func (*AgonesV1Client) GameServers ¶
func (c *AgonesV1Client) GameServers(namespace string) GameServerInterface
func (*AgonesV1Client) RESTClient ¶
func (c *AgonesV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type AgonesV1Interface ¶
type AgonesV1Interface interface {
RESTClient() rest.Interface
FleetsGetter
GameServersGetter
GameServerSetsGetter
}
type FleetExpansion ¶
type FleetExpansion interface{}
type FleetInterface ¶
type FleetInterface interface {
Create(ctx context.Context, fleet *agonesv1.Fleet, opts metav1.CreateOptions) (*agonesv1.Fleet, error)
Update(ctx context.Context, fleet *agonesv1.Fleet, opts metav1.UpdateOptions) (*agonesv1.Fleet, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, fleet *agonesv1.Fleet, opts metav1.UpdateOptions) (*agonesv1.Fleet, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*agonesv1.Fleet, error)
List(ctx context.Context, opts metav1.ListOptions) (*agonesv1.FleetList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *agonesv1.Fleet, err error)
Apply(ctx context.Context, fleet *applyconfigurationagonesv1.FleetApplyConfiguration, opts metav1.ApplyOptions) (result *agonesv1.Fleet, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, fleet *applyconfigurationagonesv1.FleetApplyConfiguration, opts metav1.ApplyOptions) (result *agonesv1.Fleet, err error)
GetScale(ctx context.Context, fleetName string, options metav1.GetOptions) (*autoscalingv1.Scale, error)
UpdateScale(ctx context.Context, fleetName string, scale *autoscalingv1.Scale, opts metav1.UpdateOptions) (*autoscalingv1.Scale, error)
FleetExpansion
}
FleetInterface has methods to work with Fleet resources.
type FleetsGetter ¶
type FleetsGetter interface {
Fleets(namespace string) FleetInterface
}
FleetsGetter has a method to return a FleetInterface. A group's client should implement this interface.
type GameServerExpansion ¶
type GameServerExpansion interface{}
type GameServerInterface ¶
type GameServerInterface interface {
Create(ctx context.Context, gameServer *agonesv1.GameServer, opts metav1.CreateOptions) (*agonesv1.GameServer, error)
Update(ctx context.Context, gameServer *agonesv1.GameServer, opts metav1.UpdateOptions) (*agonesv1.GameServer, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*agonesv1.GameServer, error)
List(ctx context.Context, opts metav1.ListOptions) (*agonesv1.GameServerList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *agonesv1.GameServer, err error)
Apply(ctx context.Context, gameServer *applyconfigurationagonesv1.GameServerApplyConfiguration, opts metav1.ApplyOptions) (result *agonesv1.GameServer, err error)
GameServerExpansion
}
GameServerInterface has methods to work with GameServer resources.
type GameServerSetExpansion ¶
type GameServerSetExpansion interface{}
type GameServerSetInterface ¶
type GameServerSetInterface interface {
Create(ctx context.Context, gameServerSet *agonesv1.GameServerSet, opts metav1.CreateOptions) (*agonesv1.GameServerSet, error)
Update(ctx context.Context, gameServerSet *agonesv1.GameServerSet, opts metav1.UpdateOptions) (*agonesv1.GameServerSet, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, gameServerSet *agonesv1.GameServerSet, opts metav1.UpdateOptions) (*agonesv1.GameServerSet, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*agonesv1.GameServerSet, error)
List(ctx context.Context, opts metav1.ListOptions) (*agonesv1.GameServerSetList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *agonesv1.GameServerSet, err error)
Apply(ctx context.Context, gameServerSet *applyconfigurationagonesv1.GameServerSetApplyConfiguration, opts metav1.ApplyOptions) (result *agonesv1.GameServerSet, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, gameServerSet *applyconfigurationagonesv1.GameServerSetApplyConfiguration, opts metav1.ApplyOptions) (result *agonesv1.GameServerSet, err error)
GetScale(ctx context.Context, gameServerSetName string, options metav1.GetOptions) (*autoscalingv1.Scale, error)
UpdateScale(ctx context.Context, gameServerSetName string, scale *autoscalingv1.Scale, opts metav1.UpdateOptions) (*autoscalingv1.Scale, error)
GameServerSetExpansion
}
GameServerSetInterface has methods to work with GameServerSet resources.
type GameServerSetsGetter ¶
type GameServerSetsGetter interface {
GameServerSets(namespace string) GameServerSetInterface
}
GameServerSetsGetter has a method to return a GameServerSetInterface. A group's client should implement this interface.
type GameServersGetter ¶
type GameServersGetter interface {
GameServers(namespace string) GameServerInterface
}
GameServersGetter has a method to return a GameServerInterface. A group's client should implement this interface.