Documentation
¶
Index ¶
- func NewFilteredFleetAutoscalerInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFleetAutoscalerInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type FleetAutoscalerInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredFleetAutoscalerInformer ¶
func NewFilteredFleetAutoscalerInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredFleetAutoscalerInformer constructs a new informer for FleetAutoscaler type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFleetAutoscalerInformer ¶
func NewFleetAutoscalerInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewFleetAutoscalerInformer constructs a new informer for FleetAutoscaler type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type FleetAutoscalerInformer ¶
type FleetAutoscalerInformer interface {
Informer() cache.SharedIndexInformer
Lister() autoscalingv1.FleetAutoscalerLister
}
FleetAutoscalerInformer provides access to a shared informer and lister for FleetAutoscalers.
type Interface ¶
type Interface interface {
// FleetAutoscalers returns a FleetAutoscalerInformer.
FleetAutoscalers() FleetAutoscalerInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.