Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FleetAutoscalerLister ¶
type FleetAutoscalerLister interface {
// List lists all FleetAutoscalers in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*autoscalingv1.FleetAutoscaler, err error)
// FleetAutoscalers returns an object that can list and get FleetAutoscalers.
FleetAutoscalers(namespace string) FleetAutoscalerNamespaceLister
FleetAutoscalerListerExpansion
}
FleetAutoscalerLister helps list FleetAutoscalers. All objects returned here must be treated as read-only.
func NewFleetAutoscalerLister ¶
func NewFleetAutoscalerLister(indexer cache.Indexer) FleetAutoscalerLister
NewFleetAutoscalerLister returns a new FleetAutoscalerLister.
type FleetAutoscalerListerExpansion ¶
type FleetAutoscalerListerExpansion interface{}
FleetAutoscalerListerExpansion allows custom methods to be added to FleetAutoscalerLister.
type FleetAutoscalerNamespaceLister ¶
type FleetAutoscalerNamespaceLister interface {
// List lists all FleetAutoscalers in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*autoscalingv1.FleetAutoscaler, err error)
// Get retrieves the FleetAutoscaler from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*autoscalingv1.FleetAutoscaler, error)
FleetAutoscalerNamespaceListerExpansion
}
FleetAutoscalerNamespaceLister helps list and get FleetAutoscalers. All objects returned here must be treated as read-only.
type FleetAutoscalerNamespaceListerExpansion ¶
type FleetAutoscalerNamespaceListerExpansion interface{}
FleetAutoscalerNamespaceListerExpansion allows custom methods to be added to FleetAutoscalerNamespaceLister.
Click to show internal directories.
Click to hide internal directories.