Documentation
¶
Overview ¶
This package has the automatically generated fake clientset.
Index ¶
- Variables
- type Clientset
- func (c *Clientset) AgonesV1() agonesv1.AgonesV1Interface
- func (c *Clientset) AllocationV1() allocationv1.AllocationV1Interface
- func (c *Clientset) AutoscalingV1() autoscalingv1.AutoscalingV1Interface
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) IsWatchListSemanticsUnSupported() bool
- func (c *Clientset) MulticlusterV1() multiclusterv1.MulticlusterV1Interface
- func (c *Clientset) Tracker() testing.ObjectTracker
Constants ¶
This section is empty.
Variables ¶
var AddToScheme = localSchemeBuilder.AddToScheme
AddToScheme adds all types of this clientset into the given scheme. This allows composition of clientsets, like in:
import ( "k8s.io/client-go/kubernetes" clientsetscheme "k8s.io/client-go/kubernetes/scheme" aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme" ) kclientset, _ := kubernetes.NewForConfig(c) _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
After this, RawExtensions in Kubernetes types will serialize kube-aggregator types correctly.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
Clientset implements clientset.Interface. Meant to be embedded into a struct to get a default implementation. This makes faking out just the method you want to test easier.
func NewClientset ¶ added in v1.48.0
NewClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.
Compared to NewSimpleClientset, the Clientset returned here supports field tracking and thus server-side apply. Beware though that support in that for CRDs is missing (https://github.com/kubernetes/kubernetes/issues/126850).
func NewSimpleClientset ¶
NewSimpleClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any field management, validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.
func (*Clientset) AgonesV1 ¶ added in v0.12.0
func (c *Clientset) AgonesV1() agonesv1.AgonesV1Interface
AgonesV1 retrieves the AgonesV1Client
func (*Clientset) AllocationV1 ¶ added in v0.12.0
func (c *Clientset) AllocationV1() allocationv1.AllocationV1Interface
AllocationV1 retrieves the AllocationV1Client
func (*Clientset) AutoscalingV1 ¶ added in v0.12.0
func (c *Clientset) AutoscalingV1() autoscalingv1.AutoscalingV1Interface
AutoscalingV1 retrieves the AutoscalingV1Client
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
func (*Clientset) IsWatchListSemanticsUnSupported ¶ added in v1.60.0
IsWatchListSemanticsSupported informs the reflector that this client doesn't support WatchList semantics.
This is a synthetic method whose sole purpose is to satisfy the optional interface check performed by the reflector. Returning true signals that WatchList can NOT be used. No additional logic is implemented here.
func (*Clientset) MulticlusterV1 ¶ added in v1.4.0
func (c *Clientset) MulticlusterV1() multiclusterv1.MulticlusterV1Interface
MulticlusterV1 retrieves the MulticlusterV1Client
func (*Clientset) Tracker ¶ added in v1.6.0
func (c *Clientset) Tracker() testing.ObjectTracker